@@ -2,6 +2,7 @@
 
 use crate::protocols::ProtocolPayload;
 use serde::{Deserialize, Serialize};
+use serde_bare::Uint;
 
 /// Request a new mailbox to be created
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
@@ -12,11 +13,11 @@ pub struct CreateStreamRequest {
 impl CreateStreamRequest {
     //noinspection ALL
     #[allow(dead_code, clippy::new_ret_no_self)]
-    pub fn new<'s, S: Into<Option<&'s str>>>(s: S) -> ProtocolPayload {
+    pub fn new<S: Into<Option<String>>>(s: S) -> ProtocolPayload {
         ProtocolPayload::new(
             "stream_create",
             Self {
-                stream_name: s.into().map(|s| s.to_string()),
+                stream_name: s.into(),
             },
         )
     }
@@ -25,18 +26,18 @@ impl CreateStreamRequest {
 /// Push a message into the mailbox
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 pub struct PushRequest {
-    pub request_id: usize, // uint
+    pub request_id: Uint, // uint
     pub data: Vec<u8>,
 }
 
 impl PushRequest {
     //noinspection ALL
     #[allow(dead_code, clippy::new_ret_no_self)]
-    pub fn new<T: Into<Vec<u8>>>(request_id: usize, data: T) -> ProtocolPayload {
+    pub fn new<T: Into<Vec<u8>>>(request_id: u64, data: T) -> ProtocolPayload {
         ProtocolPayload::new(
             "stream_push",
             Self {
-                request_id,
+                request_id: Uint(request_id),
                 data: data.into(),
             },
         )
@@ -46,21 +47,21 @@ impl PushRequest {
 /// Pull messages from the mailbox
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 pub struct PullRequest {
-    pub request_id: usize,
-    pub index: usize,
-    pub limit: usize,
+    pub request_id: Uint,
+    pub index: Uint,
+    pub limit: Uint,
 }
 
 impl PullRequest {
     //noinspection ALL
     #[allow(dead_code, clippy::new_ret_no_self)]
-    pub fn new(request_id: usize, index: usize, limit: usize) -> ProtocolPayload {
+    pub fn new(request_id: u64, index: u64, limit: u64) -> ProtocolPayload {
         ProtocolPayload::new(
             "stream_pull",
             Self {
-                request_id,
-                index,
-                limit,
+                request_id: Uint(request_id),
+                index: Uint(index),
+                limit: Uint(limit),
             },
         )
     }
@@ -70,13 +71,13 @@ impl PullRequest {
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 pub enum Index {
     Get {
-        stream_name: String,
         client_id: String,
+        stream_name: String,
     },
     Save {
-        stream_name: String,
         client_id: String,
-        index: usize,
+        stream_name: String,
+        index: Uint,
     },
 }
 
@@ -87,21 +88,21 @@ impl Index {
         ProtocolPayload::new(
             "stream_index",
             Self::Get {
-                stream_name: stream_name.into(),
                 client_id: client_id.into(),
+                stream_name: stream_name.into(),
             },
         )
     }
 
     //noinspection ALL
     #[allow(dead_code)]
-    pub fn save<S: Into<String>>(stream_name: S, client_id: S, index: usize) -> ProtocolPayload {
+    pub fn save<S: Into<String>>(stream_name: S, client_id: S, index: u64) -> ProtocolPayload {
         ProtocolPayload::new(
             "stream_index",
             Self::Save {
-                stream_name: stream_name.into(),
                 client_id: client_id.into(),
-                index,
+                stream_name: stream_name.into(),
+                index: Uint(index),
             },
         )
     }
